Event

Enum Event 

pub enum Event<'a> {
Show 16 variants Start(Tag<'a>), End(TagEnd), Text(CowStr<'a>), Code(CowStr<'a>), InlineMath(CowStr<'a>), DisplayMath(CowStr<'a>), Html(CowStr<'a>), InlineHtml(CowStr<'a>), FootnoteReference(CowStr<'a>), SoftBreak, HardBreak, Rule, TaskListMarker(bool), MdxFlowExpression(CowStr<'a>), MdxTextExpression(CowStr<'a>), MdxEsm(CowStr<'a>),
}
Markdown events that are generated in a preorder traversal of the document tree, with additional End events whenever all of an inner node’s children have been visited.

Variants



Start(Tag<'a>)

Start of a tagged element. Events that are yielded after this event and before its corresponding End event are inside this element. Start and end events are guaranteed to be balanced.



End(TagEnd)

End of a tagged element.



Text(CowStr<'a>)

A text node.

All text, outside and inside Tags.



Code(CowStr<'a>)

An inline code node.

`code`


InlineMath(CowStr<'a>)

An inline math environment node. Requires Options::ENABLE_MATH.

$math$


DisplayMath(CowStr<'a>)

A display math environment node. Requires Options::ENABLE_MATH.

$$math$$


Html(CowStr<'a>)

An HTML node.

A line of HTML inside Tag::HtmlBlock includes the line break.



InlineHtml(CowStr<'a>)

An inline HTML node.

Contains only the tag itself, e.g. <open-tag>, </close-tag> or <!-- comment -->.

Note: Under some conditions HTML can also be parsed as an HTML Block, see Tag::HtmlBlock for details.



FootnoteReference(CowStr<'a>)

A reference to a footnote with given label, defined by an event with a Tag::FootnoteDefinition tag. Definitions and references to them may occur in any order. Only parsed and emitted with Options::ENABLE_FOOTNOTES or Options::ENABLE_OLD_FOOTNOTES.

[^1]


SoftBreak

A soft line break.

Any line break that isn’t a HardBreak, or the end of e.g. a paragraph.



HardBreak

A hard line break.

A line ending that is either preceded by at least two spaces or \.

hard··
line\
breaks

· is a space



Rule

A horizontal ruler.

***
···---
_·_··_····_··

· is any whitespace



TaskListMarker(bool)

A task list marker, rendered as a checkbox in HTML. Contains a true when it is checked. Only parsed and emitted with Options::ENABLE_TASKLISTS.

- [ ] unchecked
- [x] checked


MdxFlowExpression(CowStr<'a>)

An MDX flow expression (block-level). Only parsed and emitted with Options::ENABLE_MDX.

{1 + 1}


MdxTextExpression(CowStr<'a>)

An MDX text expression (inline). Only parsed and emitted with Options::ENABLE_MDX.

a]n {expression} here


MdxEsm(CowStr<'a>)

An MDX ESM block (import/export at document level). Only parsed and emitted with Options::ENABLE_MDX.

import {Chart} from './chart.js'
export const meta = {}

Implementations

Source

impl<'a> Event<'a>

pub fn into_static(self) -> Event<'static>