LinkType

Enum LinkType 

pub enum LinkType {
    Inline,
    Reference,
    ReferenceUnknown,
    Collapsed,
    CollapsedUnknown,
    Shortcut,
    ShortcutUnknown,
    Autolink,
    Email,
    WikiLink {
        has_pothole: bool,
    },
}
Type specifier for inline links. See the Tag::Link for more information.

Variants



Inline

Inline link like [foo](bar)



Reference

Reference link like [foo][bar]



ReferenceUnknown

Reference without destination in the document, but resolved by the broken_link_callback



Collapsed

Collapsed link like [foo][]



CollapsedUnknown

Collapsed link without destination in the document, but resolved by the broken_link_callback



Shortcut

Shortcut link like [foo]



ShortcutUnknown

Shortcut without destination in the document, but resolved by the broken_link_callback

Autolink like <http://foo.bar/baz>



Email

Email address in autolink like <john@example.org>

Wikilink link like [[foo]] or [[foo|bar]]

Fields

has_pothole: bool

true if the wikilink was piped.

  • true - [[foo|bar]]
  • false - [[foo]]